@@ -2,8 +2,7 @@ from __future__ import annotations
 
 import argparse
 
-from argostranslate import package
-from argostranslate import settings
+from argostranslate import package, settings
 from argostranslate.package import AvailablePackage
 
 """
@@ -46,7 +45,7 @@ def install_all_packages():
     """Install all packages available to Argos Translate."""
     available_packages = get_available_packages()
     for available_package in available_packages:
-        install_package_print_path(available_package)
+        available_package.install()
 
 
 def install_package(args):
@@ -61,7 +60,7 @@ def install_package(args):
         for available_package in available_packages:
             name = package.argospm_package_name(available_package)
             if name == package_name:
-                install_package_print_path(available_package)
+                available_package.install()
                 break
         else:
             print("Package not found")
